reflect: unexport FFICallbackGo; use go:linkname instead

The function was always intended to be internal-only, but was exported
so that C code could call it. Now that have go:linkname for that, use it.

Change-Id: Ied5070416bb1185aa9d1d8fb81d248f90b33f5bb
Reviewed-on: https://go-review.googlesource.com/c/gofrontend/+/195857
Reviewed-by: Than McIntosh <thanm@google.com>
diff --git a/libgo/go/reflect/makefunc_ffi_c.c b/libgo/go/reflect/makefunc_ffi_c.c
index a0cfb38..e57bd51 100644
--- a/libgo/go/reflect/makefunc_ffi_c.c
+++ b/libgo/go/reflect/makefunc_ffi_c.c
@@ -25,8 +25,8 @@
    function ffiCall with the pointer to the arguments, the results area,
    and the closure structure.  */
 
-extern void FFICallbackGo(void *result, void **args, ffi_go_closure *closure)
-  __asm__ (GOSYM_PREFIX "reflect.FFICallbackGo");
+extern void ffiCallbackGo(void *result, void **args, ffi_go_closure *closure)
+  __asm__ (GOSYM_PREFIX "reflect.ffiCallbackGo");
 
 extern void makefuncfficanrecover(Slice)
   __asm__ (GOSYM_PREFIX "runtime.makefuncfficanrecover");
@@ -72,7 +72,7 @@
       makefuncfficanrecover (s);
     }
 
-  FFICallbackGo(results, args, closure);
+  ffiCallbackGo(results, args, closure);
 
   if (i < n)
     makefuncreturning ();
diff --git a/libgo/go/reflect/makefunc_ffi.go b/libgo/go/reflect/makefunc_ffi.go
index 4564736..88ffca5 100644
--- a/libgo/go/reflect/makefunc_ffi.go
+++ b/libgo/go/reflect/makefunc_ffi.go
@@ -15,19 +15,20 @@
 // The makeCIF function, implemented in the runtime package, allocates a CIF.
 func makeCIF(ft *funcType) unsafe.Pointer
 
-// FFICallbackGo implements the Go side of the libffi callback.
-// It is exported so that C code can call it.
+// Export ffiCallbackGo so that C code in makefunc_ffi_c.c can call it.
+//go:linkname ffiCallbackGo
+
+// ffiCallbackGo implements the Go side of the libffi callback.
 //
 // The call chain arriving here looks like
 //   some_go_caller
 //   ->some_ffi_internals
 //     ->ffi_callback (in C)
-//       ->FFICallbackGo
+//       ->ffiCallbackGo
 //
 // The ffi_callback handles __go_makefunc_can_recover, and
 // then passes off the data as received from ffi here.
-
-func FFICallbackGo(results unsafe.Pointer, params unsafe.Pointer, impl *makeFuncImpl) {
+func ffiCallbackGo(results unsafe.Pointer, params unsafe.Pointer, impl *makeFuncImpl) {
 	ftyp := impl.typ
 	in := make([]Value, 0, len(ftyp.in))
 	ap := params